#
# spec file for package rapid-photo-downloader
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2012 Togan Muftuoglu toganm@opensuse.org
# Copyright (c) 2009-2011 Pascal Blesser pascal.bleser@opensuse.org
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global __requires_exclude ^typelib\\(Unity\\).*$
Name:           rapid-photo-downloader
Version:        0.9.9
Release:        lp150.1.1
Summary:        Parallel downloader for camera and smartphone photos
License:        GPL-3.0+
Group:          Productivity/Graphics/Other
Url:            https://damonlynch.net/rapid/
Source:         https://launchpad.net/rapid/pyqt/%{version}/+download/%{name}-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE disable-version-check.patch
Patch0:         disable-version-check.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  update-desktop-files
Requires:       exiftool
Requires:       python3-PyPrind
Requires:       python3-arrow
Requires:       python3-colorlog
Requires:       python3-colour
Requires:       python3-easygui
Requires:       python3-gobject2
Requires:       python3-gphoto2 >= 1.4.0
Requires:       python3-psutil >= 3.4.2
Requires:       python3-pymediainfo >= 2.2.0
Requires:       python3-python-dateutil >= 2.2
Requires:       python3-pyxdg
Requires:       python3-pyzmq >=  16.0.2
Requires:       python3-qt5 >= 5.4
Requires:       python3-rawkit
Requires:       python3-sortedcontainers
Requires:       python3-tornado
BuildArch:      noarch
%if 0%{?suse_version} < 1500
Requires:       python3-scandir
Requires:       python3-typing
%endif

%description
Rapid Photo Downloader downloads images in parallel from multiple devices,
from every camera supported by gphoto2, including smartphones.

RPD has a timeline, which groups photos and videos based on how much
time elapsed between consecutive shots. It can be used to identify
photos and videos taken at different periods in a single day or over
consecutive days.

%lang_package

%prep
%setup -q
%patch0 -p1
rm -rf rapid_photo_downloader.egg-info
find raphodo -type f -name '*.py' -exec sed -i -e '/^#!\//, 1d' {} \;

%build
python3 setup.py build

%install
python3 setup.py install \
    --prefix="%{_prefix}" \
    --root=%{buildroot}

%find_lang %{name}
%fdupes -s %{buildroot}

%files
%doc README.rst CHANGES.rst
%{_bindir}/analyze-pv-structure
%{_bindir}/%{name}
%{_datadir}/appdata/net.damonlynch.%{name}.appdata.xml
%{_datadir}/applications/net.damonlynch.%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg
%dir %{_datadir}/solid
%dir %{_datadir}/solid/actions
%{_datadir}/solid/actions/net.damonlynch.%{name}.desktop
%{_mandir}/man1/analyze-pv-structure.1%{ext_man}
%{_mandir}/man1/%{name}.1%{ext_man}
%{python3_sitelib}/raphodo
%{python3_sitelib}/rapid_photo_downloader-%{version}-py%{python3_version}.egg-info

%files lang -f %{name}.lang

%changelog
* Tue Apr 24 2018 aloisio@gmx.com
- Update to version 0.9.9
  * Fix bug #1750879: Sequence numbers increment incorrectly for
    videos when Synchronize RAW+JPEG enabled.
  * Fix bug in sequence letter generation.
  * Enable the disabling of new version checks in both the
    program logic and the user interface, which is useful for
    Linux distributions. To disable the check, Linux package
    maintainers should patch the file constants.py to
    change the line `disable_version_check = False` to
    `disable_version_check = True`.
  * Include tornado as a dependency instead of relying on the
    deprecated mini-tornado found in pyzmq.
  version 0.9.8:
  * On Sony files, use ExifTool to get shutter count metadata.
    Please note, not all Sony models produce this metadata.
- Added disable-version-check.patch
* Tue Jan 30 2018 jengelh@inai.de
- Replace description to say something about the software's
  functionality.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to version 0.9.7
  * Fixed bug where removing a download source while another source
    was being scanned could cause a crash when the timeline was
    scrolled.
  * Fixed bug where session sequence values were being reset every
    time a download was initiated, not every time the program was
    started.
  * Updated German, Hungarian and Norwegian Bokmal translations.
  * Fix bug #1738174: Don't crash when right clicking in thumbnail
    checkbox and no thumbnail is selected.
  * Fix bug #1737416: Don't scan cameras when browsing "This
    Computer", and detect if a camera mount has been passed via
    the command line (which can happen when the program
    automatically launches in response to a camera being attached
    to the computer).
  * When opening a file in KDE's Dolphin file manager, select the
    file (and thus highlight it), like is done with Gnome Files and
    several other file managers.
  * Fix bug #1737287: Don't allow identical entries in subfolder
    generation and file renaming presets, where the preset names
    differ but their content is the same.
  version  0.9.6:
  * When scrolling is synchronized, and you click on a thumbnail,
    the top of the Timeline will be scrolled match to match it.
  * Don't crash when only new files are displayed and the Timeline
    is scrolled when scrolling is synchronized.
  * Updated Czech, Dutch, Hungarian, Japanese, Russian, and Spanish
    translations.
  * Don't crash when Timeline ranges are selected and scrolling is
    synchronized.
  * The Timeline is now shown by default when the program is first
    run, or settings are reset.
  * Added option to synchronize Timeline with thumbnails. Scroll
    one, and the other automatically scrolls too. Use the button
    at the bottom-right of the Timeline to toggle this feature.
  * After clearing a Timeline selection, the display of thumbnails
    will be positioned such that the the photos in the previous
    selection are visible. Previously, the thumbnails display would
    be scrolled all the way to the top after the Timeline selection
    had been cleared.
  * Added Hasselblad 3FR files to list of supported file formats.
    If you detect any problems with the accuracy of the metadata
    from this format, please let me know.
  * Work around MediaInfoLib bug #695 that caused the libmediainfo
    shared object file to be named incorrectly, making it appear
    to be missing.
  * Correctly parse Distribution version in installer when running
    on Fedora, Debian and Peppermint.
  * Install PyQt 5.9.2 or greater. Upgrade pymediainfo to version
    2.2.0 or newer.
  * Updated Catalan, Chinese, Czech, Danish, Dutch, French, German,
    Norwegian Nyorsk, Russian, and Spanish translations.
  version 0.9.5:
  * Added check to install.py installation script and upgrade.py
    upgrade script to ensure that SIP 4.19.3 is installed when
    PyQt 5.9 is installed. The combination of SIP  4.19.4 and
    PyQt 5.9 causes Rapid Photo Downloader to crash. Because SIP
    4.19.4 is installed by default when installing PyQt 5.9, the
    install and upgrade scripts forcibly revert to
    SIP 4.19.3 when PyQt 5.9 is installed.
  * Add option to manually mark files as previously downloaded,
    allowing for occasions when another program has already
    downloaded the files. Right-click on one or more photo or video
    thumbnails to mark them as previously downloaded.
  * Add elementary OS to list of Linux distributions supported by
    the install.py script.
  * Fixed bug in upgrade script when reporting an operational
    failure.
  * Updated Chinese, Dutch, Italian, and Norwegian Bokmal
    translations.
  version 0.9.4:
  * Workaround bug in iOS devices that create on-the-fly subfolders
    from which to download that vary each time the device is
    initialized.
  * Add progress bars and badge counts when running under Ubuntu
    17.10's Dash to Dock extension.
  * Don't crash when locale is not correctly set.
  * Updated Dutch, French and German translations.
* Fri Sep 15 2017 aloisio@gmx.com
- Added python3-pyzmq version requirement
* Fri Sep 15 2017 zaitor@opensuse.org
- Update to version 0.9.3:
  + When requesting GIO to unmount a camera / phone so it can be
    accessed by libgphoto2, retry several times if it fails.
    Sometimes a GIO client program such as Gnome Files needs a few
    seconds to relinquish control of the device.
  + Fixed bug where a crash could occur when removing a camera that
    was in the preliminary stages of being scanned.
  + Fixed a bug introduced in 0.9.3b1 where photo and video numbers
    and sizes were not displayed in the devices summary in the
    program's left-hand pane.
  + Fixed a bug on Fedora where the maximum length for an sqlite3
    query could be exceeded.
  + When running a user-installed python such as Anaconda or
    another custom python, where possible the install.py script now
    switches over to using the Linux distribution's system python.
  + Under Python 3.6 or newer, bumped required version of pyzmq up
    to 16.0.2, hopefully avoiding a segfault observed with pyzmq
    15.1.0 and ZeroMQ 4.1.5. See the Release Notes for more
    details.
  + Updated translations.
* Mon Sep 11 2017 dimstar@opensuse.org
- Use automatic dependencies detection for typelib():
  + Add gobject-introspection BuildRequires (which contains the
    parser and rpm logic).
  + Drop the static typelib-1_0-* Requires.
  + As openSUSE does not provide Unity, filter out typelib(Unity)
    from the automatic dependency list.
* Sun Sep 10 2017 aloisio@gmx.com
- Added missing runtime dependency, fixes (boo#1057972)
* Mon Aug 28 2017 aloisio@gmx.com
- Set correct license
* Sun Aug 27 2017 aloisio@gmx.com
- Update to version 0.9.2
  * When displaying the time in the Timeline in a locale that
    does not use a twelve hour clock, correctly display the time
    using the 24 hour clock. If the times or dates being displayed
    in the Timeline are not displayed correctly in your language,
    please file a bug report.
  * Fixed a bug where an exception could occur when clicking on
    some Timeline entries or displaying their thumbnails as a
    tooltip. It occurred when the Timeline had one or more entries
    in the right-most column that spanned more than one calendar
    day. The code that generates the Timeline is among the most
    complex in the application. If you notice any problems, please
    file a bug report.
  * When a download device is inserted and downloaded files are
    already in the main window, the program will now ask if the
    completed downloads should be cleared. A new, associated program
    preference controls if the program should query and what action
    to take.
  * Improved visual appearance of preferences window.
  * Fixed a bug where the thumbnail extractors might crash when
    the thumbnail cache database had not yet been created, which
    could happen in unusual circumstances such as when the disk was
    under particularly heavy load.
  * Fixed bug extracting date/time metadata from videos where
    devices that create videos from which metadata cannot be
    extracted until the entire video is downloaded from the device.
  * When running LXQt, now assume the default file manager is
    pcmanfm-qt, regardless of what the mime-type handler reports.
    URIs passed to it now have the specific file stripped from the
    path, avoiding errors with pcmanfm-qt opening it. Currently,
    compared to more mature platforms like Gnome, LXQt has
    limitations that limit Rapid Photo Downloader's
    functionality.
  * Added uninstall and uninstall including dependencies options
    to the install.py script.
  * Added localization to the install.py script. The install
    script now embeds the files needed for localization, and
    utilizes them if needed.
  * The install.py script now checks key installation folders for
    ownership and permission problems, fixing them if necessary.
  * The install.py script now correctly parses openSUSE's zypper
    output to ascertain distribution packages that are already
    installed, saving time during installation.
  * In install.py, catch return code 104 from zypper se when no
    package is found.
  * Added support for Peppermint OS to the install.py script.
  * Terminate program at startup if the program's own module
    imports are being loaded from conflicting sources, indicating
    more than one copy of the program has been installed.
  * Report gphoto2 errors on the command line and Error Reports
    window with the name of the error rather than its numeric code.
  * Catch file permission errors more effectively in copy, rename,
    and backup processes.
  * Fixed bug when deleting certain sample videos from a device
    that had already been removed.
  * Updated Belarusian, Chinese (Simplified), Czech, Dutch, French,
    German, Hungarian, Japanese, Norwegian Bokmal, Norwegian
    Nynorsk, Russian and Spanish translations.
  * Applied a patch from Mikael Wiesel to fix a bug where several
    strings were not available for translation. Additionally made
    available for translation some buttons whose text was
    untranslated. Moreover, humanized times such as "one hour ago"
    (all of which are generated using the python library Arrow)
    are now localized where Arrow supports it. Finally,
    date/times in tooltips that appear over thumbnails are now
    localized, and locale date / times are used in download
    subfolder and filename generation for values like months.
* Sat Jul 15 2017 aloisio@gmx.com
- Update to version 0.9.1 (see CHANGES.rst)
- Switched to python3
- Split separate -lang file
- Dropped rapid-photo-downloader-rpmlintrc
- Spec cleanup
* Tue Jan  6 2015 firebird209@gmail.com
- Update to 0.4.11 For details see Changelog
  * Updated Brazilian, Catalan, Croatian, Czech, German, Japanese,
    Norwegian, Polish, Portuguese and Swedish translations.
  * Fixed crash on systems using the library Pillow 3.0.
  * Updated AppData file.
* Tue Mar  4 2014 toganm@opensuse.org
- Update to 0.4.10 For details see Changelog
  * Updated Catalan and Portuguese translations.
  * Fixed bug in translations for term "Back up".
* Tue Jan 28 2014 toganm@opensuse.org
- Update to 0.4.9 For details see Changelog
  * Updated Catalan and Spanish and Swedish translations.
  * Fixed occasional incorrect use of term "backup".
* Wed Jan 15 2014 toganm@opensuse.org
- Update to 0.4.8 For details see Changelog
  * Fixed bug lp#1263237: Added support for MPO files (3D images).
  * Fixed bug lp#1263483: Some terms in the user interface are not
    being translated.
  * Updated Dutch, French Italian, Polish and Spanish translations.
* Thu Oct 24 2013 toganm@opensuse.org
- Update to 0.4.7 For details see Changelog
  * Added feature to download audio files that are associated with
    photos such as those created by the Canon 1D series of cameras.
  * Fixed bug #1242119: In Ubuntu 13.10, choosing a destination or
    source folder from its bookmark does not work. The correct value
    is displayed in the file chooser button, but this value is not
    used by Rapid Photo Downloader. Earlier versions of Ubuntu were
    unaffected.
  * Fixed bug #1206853: Crashes when system message notifications not
    functioning properly.
  * Fixed bug #909405: Allow selections by row (and not GTK default
    by square) when user is dragging the mouse or using the keyboard
    to select.
  * Added a KDE Solid action. Solid is KDE4's hardware-related
    framework. It detects when the user connects a new device and
    display a list of related actions. Thanks to dju` for the patch.
  * Added Belarusian translation—thanks go to Ilya Tsimokhin. Updated
    Swedish and Ukrainian translations.
* Thu Jan 24 2013 toganm@opensuse.org
- Update to 0.4.6 For details see Changelog
  * Fixed bug lp#1083756: Application shows duplicate sources.
  * Fixed bug lp#1093330: Photo rename ignores SubSeconds when 00.
  * Updated German and Spanish translations.
  * Added extra debugging output to help trace program execution
    progress.
- added fdupes to buildrequires to fix duplicate files
* Thu Jul  5 2012 toganm@opensuse.org
- removed man page compression as rpm does this byitself
* Wed Jul  4 2012 toganm@opensuse.org
- Update to 0.4.5 For details see Changelog
  * Updated Dutch, Estonian, German, Italian, Norwegian and Polish
    translations.
  * Updated man page.
  * Fixed bug #1014203: Very poor program performance after download
    device changed. The program now displays the results of scanning
    files much quicker if the program's download device preferences
    are changed and a scan begins of a new device.
  * Fixed bug #1014219: File Modify process crashes if program exits
    during download.
* Wed May 30 2012 toganm@opensuse.org
- Update to 0.4.4 For details see Changelog
  * Fixed bug #998320: Applied patch from Dmitry Kazimirov for
    option to have subfolder generation and file renaming use a
    month in text format.
  * Fixed bug #986681: Crash when showing question dialog on some
    non-Gnome systems.
  * Fixed bug #995769: The Help button in the preferences dialog
    does not work.
  * Fixed bug #996613: Updated Free Software Foundation address.
  * Added Estonian translation. Updated Brazilian, Dutch, French,
    German, Norwegian Bokmal, Polish, Spanish and Russian
    translations.
* Tue May  8 2012 toganm@opensuse.org
- add perl-Image-ExifTool gdk-pixbuf-loader-rsvg to requires
* Tue May  1 2012 toganm@opensuse.org
- update to 0.4.3 For details see ChangeLog :
  * ExifTool is now a required dependency for Rapid Photo Downloader.
    ExifTool can be used to help download videos on Linux distributions
    that have not packaged hachoir-metadata.
  * Exiftran is another new dependency. It is used to automatically
    rotate JPEG images.
  * Fixed bug #704482: Delete photos option should be easily accessible
  * Fixed bug #754531: extract Exif.CanonFi.FileNumber metadata
  * Fixed bug #695517: Added functionality to download MTS video files.
  * Fixed bug #859998: Download THM video thumbnail files
  * Fixed bug #594533: Lossless JPEG rotation based on EXIF data after
    picture transfer
  * Fixed bug #859012: Confirm if really want to download from /home,
    /media or /
- Use the original source files
- Follow openSUSE license format
- Include ChangeLog AUTHORS COPYING in the docs
- Use license for the spec itself
* Fri Apr 29 2011 pascal.bleser@opensuse.org
- update to 0.4.0:
  * clean new user interface
  * imports about 3 times faster
  * ability to select multiple files to check or uncheck for downloading
  * adds automation feature to delete downloaded files from a device
  * backups have been implemented
  * adds a preferences option for disabling thumbnail generation
  * fixes a crash that occurred when downloading some files after having
    previously downloaded others in the same session
  * adds Job Code functionality
  * adds an eject device button for each unmountable device
  * adds display of remaining files to be downloaded in the progress bar
  * adds display of overall download progress in the lower progress bar
  * adds display of time remaining and download speed in the status bar
  * adds system notification messages
  * adds new automation features: auto download, auto exit, and auto unmount
  * bugfix: display file and subfolder naming warnings in error log
  * adds an error log window to display download warnings and errors
  * adds a feature to synchronize RAW + JPEG sequence values
* Fri Mar 25 2011 pascal.bleser@opensuse.org
- update to 0.3.5:
  * fix bug #714039, where under certain circumstances the program could crash
    while downloading files
  * added Romanian translation. Updated Brazilian, Chinese, Croatian, Czech,
    Dutch, Finnish, German, Italian, Polish and Russian translations
* Sun Jan  2 2011 pascal.bleser@opensuse.org
- update to 0.3.4:
  * you can now zoom in and out of a preview image
  * extraneous white space is now more effectively stripped from serial number metadata and folder names
  * a Croatian translation was added
  * the French, Norwegian Bokmal, Polish, and Russian translations were updated
  * other minor fixes were made
* Wed Oct 27 2010 pascal.bleser@opensuse.org
- update to 0.3.3:
  * adds support for mod, tod, and 3gp video files
  * adds preliminary support for Samusung SRW files
  * generation of subfolders and filenames using the time a download was started
  * hachoir-metadata is now used to extract selected metadata from video files
  * fixes for bugs related to a missing video download directory at program startup
  * a command line option to output to the terminal information, which is useful for debugging
  * Norwegian Bokmal and Portuguese translations
  * updates to many other translations
* Mon Sep 13 2010 pascal.bleser@opensuse.org
- update to 0.3.2:
  * adds a Norwegian Nynorsk translation
  * updates the Chinese, Finnish, Hungarian, Dutch, Occitan (post 1500), Polish, Brazilian Portuguese, and Russian translations
  * fixes crash on startup when checking for free space and the download folder does not exist
* Fri Aug 13 2010 pascal.bleser@opensuse.org
- update to 0.3.1:
  * main window now works more effectively on tiny screens like netbooks
  * amount of free space available on the filesystem where photos are to be downloaded is now displayed in the status bar
  * added or updated many translations: Chinese (simplified), Bulgarian, Japanese, Occitan (post 1500), Persian, Portuguese (Brazilian), and Turkish have been added; updated Finnish, French, Hungarian, Russian, Serbian and Spanish translations
* Sun Jul 11 2010 pascal.bleser@opensuse.org
- update to 0.3.0:
  * the major new feature of this release is the generation of previews before a download takes place: you can now select which photos and videos you wish to download
  * you can now assign different job codes to photos and videos in the same download: simply select photos and videos, and from the main window choose a job code for them
  * the errors and warnings reported have been completely overhauled, and are now more concise
* Mon Jun  7 2010 pascal.bleser@opensuse.org
- update to 0.2.2:
  * adds an Ukranian translation
  * no longer crashes on startup when exiv2 is not installed
* Sun Jun  6 2010 pascal.bleser@opensuse.org
- update to 0.2.1:
  * Bug fix: display sample photo and video names in preferences
    dialog using first photo and video found on download device,
    where possible -- this used to work but was inadvertently
    disabled in a recent release
  * Bug fix: prompt for Job code when only video names or video
    subfolder names use a job code
  * bug fix: filter out Null bytes from Exif string values -- these
    can occur when the Exif data is corrupted
  * translation updates for Spanish, Russian and Finnish
* Mon May 31 2010 pascal.bleser@opensuse.org
- update to 0.2.0:
  * video download functionality was added
  * the use of version 0.2.x of the pyexiv2 library was enabled
  * a bug in which sometimes images could not be downloaded to NTFS
    partitions was fixed
  * error message headings in the Error Log are now displayed in a
    red font
  * program settings and preferences can be reset using a new
    command line option
* Sun Feb 14 2010 pascal.bleser@opensuse.org
- update to 0.1.3:
  * fixed bug #509348: when both the backup and "Delete images
    from image device upon download completion" options are
    selected, the program will only delete an image from the image
    device if it was both downloaded to the download folder and
    backed up; previously it did not check to ensure it was backed
    up correctly too
  * fixed bug #505492: the program previously failed to start in
    environments where the notification system has problems
  * fixed bug #508304: the user is now prompted to confirm if they
    really want to remove all of their Job Codes after clicking on
    "Remove All" in the preferences dialog window
  * fixed bug #510484: previously, the program could crash when
    attempting to download to a read-only folder
  * fixed bug #510516: the program now checks to see if the
    download folder exists and is writeable; if automatic detection
    of image devices is not enabled, it checks to see if the image
    location path exists
- changes from 0.1.2:
  * new feature: photographers using RAW + JPEG mode now have the
    option to synchronize sequence numbers for the matching pair
    of images: this option is useful if you use the RAW + JPEG
    feature on your camera and you use sequence numbers or letters
    in your image renaming; enabling this option will cause the
    program to detect matching pairs of RAW and JPEG images, and
    when they are detected, the same sequence numbers and letters
    will be applied to both image names; furthermore, sequences
    will be updated as if the images were one
  * increased maximum sequence number length to seven digits by
    user request
  * fixed bug #503704: changes in values for downloads today and
    stored number not updated when changed via program preferences
    while a download is ready to begin
- changes from 0.1.1:
  * aded auto delete feature. When enabled, upon the completion of
    a download, images that were successfully downloaded will be
    deleted from the image device they were downloaded from;
    images that were not downloaded successfully will not be
    deleted
  * added keyboard accelerators for Preferences and Help
- changes from 0.1.0:
  * added icons to notification messages
  * bug fix: properly handle devices being unmounted, fixing a bug
    introduced in Version 0.0.9 beta 2
  * bug fix: when program preferences are changed, image and backup
    devices are now refreshed only when the preferences dialog
    window is closed
  * bug fix: minutes component of image and folder renaming had the
    same code as months
  * fixed bug #484432: error in adding job codes via the
    preferences dialog
  * fixed bug #486886: job code prompt can appear multiple times
  * added a "Job codes" option
  * added additional hour, minute and second options in image
    renaming and subfolder creation
  * fixed bug #478620: problem with corrupted image files
  * fixed bug #479424: some camera model names do not have numbers,
    but it still makes sense to return a shortened name
  * fixed bug #482831: program no longer crashes when auto-download
    is off, and a device is inserted before another download has
    completed
* Sat Oct 17 2009 pascal.bleser@opensuse.org
- initial package: 0.0.10
